==> spring-cloud-contract-verifier-2.2.1.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/file/SingleContractMetadata.java <==
package org.springframework.cloud.contract.verifier.file;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@groovy.transform.CompileStatic() @groovy.transform.EqualsAndHashCode(excludes={"contractMetadata"}) @groovy.transform.ToString(excludes={"contractMetadata"}) public class SingleContractMetadata
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public SingleContractMetadata
(org.springframework.cloud.contract.spec.Contract currentContract, org.springframework.cloud.contract.verifier.file.ContractMetadata contractMetadata) {}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public final  org.springframework.cloud.contract.verifier.file.ContractMetadata getContractMetadata() { return (org.springframework.cloud.contract.verifier.file.ContractMetadata)null;}
public final  org.springframework.cloud.contract.spec.Contract getContract() { return (org.springframework.cloud.contract.spec.Contract)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getInputStubContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getEvaluatedInputStubContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getOutputStubContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getEvaluatedOutputStubContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getInputTestContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getEvaluatedInputTestContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getOutputTestContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getEvaluatedOutputTestContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public  boolean isJson() { return false;}
public  boolean evaluatesToJson() { return false;}
public  boolean isIgnored() { return false;}
public  boolean isXml() { return false;}
public  boolean isHttp() { return false;}
public  boolean isInProgress() { return false;}
public  boolean isMessaging() { return false;}
public  java.lang.String methodName() { return (java.lang.String)null;}
}

==> spring-cloud-contract-verifier-2.2.3.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/file/SingleContractMetadata.java <==
package org.springframework.cloud.contract.verifier.file;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@groovy.transform.CompileStatic() @groovy.transform.EqualsAndHashCode(excludes={"contractMetadata"}) @groovy.transform.ToString(excludes={"contractMetadata"}) public class SingleContractMetadata
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public SingleContractMetadata
(org.springframework.cloud.contract.spec.Contract currentContract, org.springframework.cloud.contract.verifier.file.ContractMetadata contractMetadata) {}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public final  org.springframework.cloud.contract.verifier.file.ContractMetadata getContractMetadata() { return (org.springframework.cloud.contract.verifier.file.ContractMetadata)null;}
public final  org.springframework.cloud.contract.spec.Contract getContract() { return (org.springframework.cloud.contract.spec.Contract)null;}
public final  java.lang.String getDefinedInputStubContentType() { return (java.lang.String)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getInputStubContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getEvaluatedInputStubContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  java.lang.String getDefinedOutputStubContentType() { return (java.lang.String)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getOutputStubContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getEvaluatedOutputStubContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  java.lang.String getDefinedInputTestContentType() { return (java.lang.String)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getInputTestContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getEvaluatedInputTestContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  java.lang.String getDefinedOutputTestContentType() { return (java.lang.String)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getOutputTestContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public final  org.springframework.cloud.contract.verifier.util.ContentType getEvaluatedOutputTestContentType() { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public  boolean isJson() { return false;}
public  boolean evaluatesToJson() { return false;}
public  boolean isIgnored() { return false;}
public  boolean isXml() { return false;}
public  boolean isHttp() { return false;}
public  boolean isInProgress() { return false;}
public  boolean isMessaging() { return false;}
public  java.lang.String methodName() { return (java.lang.String)null;}
}
